@@ -23,7 +23,7 @@ from gi.repository import GLib
 
 OCRFEEDER_STUDIO_NAME = 'OCRFeeder'
 OCRFEEDER_COMPACT_NAME = 'ocrfeeder'
-OCRFEEDER_STUDIO_VERSION = '0.8.3'
+OCRFEEDER_STUDIO_VERSION = '0.8.4'
 OCRFEEDER_STUDIO_AUTHORS = ['Joaquim Rocha <me@joaquimrocha.com>']
 OCRFEEDER_STUDIO_ARTISTS = ['Joaquim Rocha <me@joaquimrocha.com>']
 OCRFEEDER_COPYRIGHT = 'Copyright © 2008-2014 Joaquim Rocha\n' \
@@ -93,7 +93,14 @@ OCRFEEDER_SPELLCHECKER_UI = os.path.join(RESOURCES_DIR, 'spell-checker.ui')
 OCRFEEDER_MENUBAR_UI = os.path.join(RESOURCES_DIR, 'menubar.ui')
 
 # ISO-codes location
-ISO_CODES_PATH = '/usr/share/xml/iso-codes/'
+iso_codes_dir = os.environ.get('ISO_CODES_DIR')
+if iso_codes_dir is None:
+    for dir in GLib.get_system_data_dirs():
+        iso_codes_dir = os.path.join(dir, 'xml', 'iso-codes')
+        if os.path.isdir(iso_codes_dir):
+            break
+
+ISO_CODES_PATH = iso_codes_dir
 
 APP_ID = 'org.gnome.OCRFeeder'
 
